@@ -15,7 +15,7 @@ from selenium.webdriver.support.wait import WebDriverWait
 
 from je_web_runner.je_web_runner.web_element_wrapper import web_element_wrapper
 from je_web_runner.je_web_runner.webdriver_with_options import set_webdriver_options_capability_wrapper
-from je_web_runner.utils.assert_value.result_check import check_webdriver
+from je_web_runner.utils.assert_value.result_check import check_webdriver_details
 from je_web_runner.utils.exception.exception_tag import selenium_wrapper_web_driver_not_found_error
 from je_web_runner.utils.exception.exceptions import WebRunnerException, WebRunnerWebDriverIsNoneException
 from je_web_runner.utils.exception.exceptions import WebRunnerWebDriverNotFoundException
@@ -67,12 +67,12 @@ class WebDriverWrapper(object):
     def set_driver(self, webdriver_name: str,
                    webdriver_manager_option_dict: dict = None, **kwargs) -> \
             Union[
-            webdriver.Chrome,
-            webdriver.Chrome,
-            webdriver.Firefox,
-            webdriver.Edge,
-            webdriver.Ie,
-            webdriver.Safari,
+                webdriver.Chrome,
+                webdriver.Chrome,
+                webdriver.Firefox,
+                webdriver.Edge,
+                webdriver.Ie,
+                webdriver.Safari,
             ]:
         """
         :param webdriver_name: which webdriver we want to use
@@ -107,12 +107,12 @@ class WebDriverWrapper(object):
 
     def set_webdriver_options_capability(self, key_and_vale_dict: dict) -> \
             Union[
-            webdriver.Chrome,
-            webdriver.Chrome,
-            webdriver.Firefox,
-            webdriver.Edge,
-            webdriver.Ie,
-            webdriver.Safari,
+                webdriver.Chrome,
+                webdriver.Chrome,
+                webdriver.Firefox,
+                webdriver.Edge,
+                webdriver.Ie,
+                webdriver.Safari,
             ]:
         """
         :param key_and_vale_dict: use to set webdriver capability
@@ -165,7 +165,7 @@ class WebDriverWrapper(object):
 
     def find_element_with_test_object_record(self, element_name: str) -> WebElement:
         """
-        this is executor use but still can normal use
+        this is executor use but still can normally use
         :param element_name: test object name
         :return: fined web element
         """
@@ -185,7 +185,7 @@ class WebDriverWrapper(object):
 
     def find_elements_with_test_object_record(self, element_name: str) -> List[WebElement]:
         """
-        this is executor use but still can normal use
+        this is executor use but still can normally use
         :param element_name: test object name
         :return: list include fined web element
         """
@@ -206,6 +206,7 @@ class WebDriverWrapper(object):
     # wait
     def implicitly_wait(self, time_to_wait: int) -> None:
         """
+        selenium implicitly_wait
         :param time_to_wait: how much time we want to wait
         :return: None
         """
@@ -219,6 +220,7 @@ class WebDriverWrapper(object):
 
     def explict_wait(self, wait_time: int, statement: bool, until_type: bool = True):
         """
+        selenium explict_wait
         :param wait_time: how much time we want to wait if over-time will raise an exception
         :param statement: a program statement should be return True or False
         :param until_type: what type until wait True is until False is until_not
@@ -240,6 +242,7 @@ class WebDriverWrapper(object):
 
     def to_url(self, url: str) -> None:
         """
+        to url
         :param url: what url we want redirect to
         :return: None
         """
@@ -290,6 +293,7 @@ class WebDriverWrapper(object):
     # webdriver new page
     def switch(self, switch_type: str, switch_target_name: str = None):
         """
+        switch to target element
         :param switch_type: what type switch? one of  [active_element, default_content, frame,
         parent_frame, window, alert]
         :param switch_target_name: what target we want to switch use name to search
@@ -327,7 +331,7 @@ class WebDriverWrapper(object):
             record_action_to_list("webdriver wrapper switch", param, error)
 
     # timeout
-    def set_script_timeout(self, time_to_wait) -> None:
+    def set_script_timeout(self, time_to_wait: int) -> None:
         """
         set max script execute time
         :param time_to_wait: how much time we want to wait if over-time will raise an exception
@@ -341,7 +345,7 @@ class WebDriverWrapper(object):
             print(repr(error), file=stderr)
             record_action_to_list("webdriver wrapper set_script_timeout", param, error)
 
-    def set_page_load_timeout(self, time_to_wait) -> None:
+    def set_page_load_timeout(self, time_to_wait: int) -> None:
         """
         set page load max wait time
         :param time_to_wait: how much time we want to wait if over-time will raise an exception
@@ -368,7 +372,7 @@ class WebDriverWrapper(object):
             print(repr(error), file=stderr)
             record_action_to_list("webdriver wrapper get_cookies", None, error)
 
-    def get_cookie(self, name) -> dict:
+    def get_cookie(self, name: str) -> dict:
         """
         use to get current page cookie
         :param name: use cookie name to find cookie
@@ -436,7 +440,7 @@ class WebDriverWrapper(object):
             print(repr(error), file=stderr)
             record_action_to_list("webdriver wrapper execute", param, error)
 
-    def execute_script(self, script, *args) -> None:
+    def execute_script(self, script: str, *args) -> None:
         """
         execute script
         :param script: script to execute
@@ -589,12 +593,12 @@ class WebDriverWrapper(object):
             print(repr(error), file=stderr)
             record_action_to_list("webdriver wrapper drag_and_drop_offset", param, error)
 
-    def drag_and_drop_offset_with_test_object(self, element_name: str, target_x: int, target_y: int) -> None:
+    def drag_and_drop_offset_with_test_object(self, element_name: str, offset_x: int, offset_y: int) -> None:
         """
         drag web element to target element then drop with offset and test object
         :param element_name: test object name
-        :param target_x: offset x
-        :param target_y: offset y
+        :param offset_x: offset x
+        :param offset_y: offset y
         :return: None
         """
         param = locals()
@@ -603,7 +607,7 @@ class WebDriverWrapper(object):
                 test_object_record.test_object_record_dict.get(element_name).test_object_type,
                 test_object_record.test_object_record_dict.get(element_name).test_object_name
             )
-            self._action_chain.drag_and_drop_by_offset(element, target_x, target_y)
+            self._action_chain.drag_and_drop_by_offset(element, offset_x, offset_y)
             record_action_to_list("webdriver wrapper drag_and_drop_offset_with_test_object", param, None)
         except Exception as error:
             print(repr(error), file=stderr)
@@ -1073,7 +1077,7 @@ class WebDriverWrapper(object):
             print(repr(error), file=stderr)
             record_action_to_list("webdriver wrapper get_window_position", None, error)
 
-    def set_window_rect(self, x=None, y=None, width=None, height=None) -> dict:
+    def set_window_rect(self, x: int = None, y: int = None, width: int = None, height: int = None) -> dict:
         """
         only supported for w3c compatible another browsers need use set_window_position or set_window_size
         :param x: set x coordinates
@@ -1138,7 +1142,7 @@ class WebDriverWrapper(object):
         """
         param = locals()
         try:
-            check_webdriver(self.current_webdriver, check_dict)
+            check_webdriver_details(self.current_webdriver, check_dict)
             record_action_to_list("webdriver wrapper check_current_webdriver", param, None)
         except Exception as error:
             print(repr(error), file=stderr)
